==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfileexporterexternal.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTEREXTERNAL_H
#define BIBTEXBIBTEXFILEEXPORTEREXTERNAL_H

#include <bibtexfileexporter.h>
#include <settings.h>

class QWaitCondition;
class QProcess;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterExternal : public BibTeXFileExporter
    {
        Q_OBJECT
    public:
        BibTeXFileExporterExternal( Settings::Exporter exporter, Settings::FileFormat fileformat );
        ~BibTeXFileExporterExternal();

        bool save( QIODevice* iodevice, BibTeXFile* bibtexfile );
        bool save( QIODevice* iodevice, BibTeXElement* element );

    private:
        QWaitCondition *wc;
        QProcess *process;
        QTextStream *writeTo;
        Settings::Exporter m_exporter;
        Settings::FileFormat m_fileformat;

        bool generateOutput( QBuffer &input, QIODevice* output );

    private slots:
        void slotProcessExited();
        void slotReadProcessOutput();
        void slotWroteToStdin();

    };

}

#endif

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfileexporterexternal.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTEREXTERNAL_H
#define BIBTEXBIBTEXFILEEXPORTEREXTERNAL_H

#include <bibtexfileexporter.h>
#include <settings.h>

class QWaitCondition;
class QProcess;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterExternal : public BibTeXFileExporter
    {
        Q_OBJECT
    public:
        BibTeXFileExporterExternal( KBibTeX::Settings::Exporter exporter, KBibTeX::Settings::FileFormat fileformat );
        ~BibTeXFileExporterExternal();

        bool save( QIODevice* iodevice, BibTeXFile* bibtexfile, QStringList *errorLog = NULL );
        bool save( QIODevice* iodevice, BibTeXElement* element, QStringList *errorLog = NULL );

    private:
        QWaitCondition *wc;
        QProcess *process;
        QTextStream *writeTo;
        KBibTeX::Settings::Exporter m_exporter;
        KBibTeX::Settings::FileFormat m_fileformat;

        bool generateOutput( QBuffer &input, QIODevice* output );

    private slots:
        void slotProcessExited();
        void slotReadProcessOutput();
        void slotWroteToStdin();

    };

}

#endif
